@@ -25,6 +25,7 @@ from suanpan.stream.interfaces import HasHandlers
 from suanpan.stream.objects import Context
 from suanpan.stream.sio import StreamServer, WebSocketHandler
 from suanpan.utils import functional, json, port
+from suanpan.path import rootDir
 
 
 class Stream(
@@ -388,7 +389,11 @@ class StreamSIOLoop(StreamBaseLoop):
 
     @functional.lazyproperty
     def staticFolder(self):
-        return self.stream.options["stream-sio-static-folder"]
+        root = rootDir()
+        staticF = self.stream.options["stream-sio-static-folder"]
+        if root:
+            return os.path.join(root, os.path.relpath(staticF, "/"))
+        return staticF
 
     @functional.lazyproperty
     def staticUrlPrefix(self):
@@ -477,7 +482,7 @@ class StreamSIOLoop(StreamBaseLoop):
         for _ in range(20):
             try:
                 p = port.get_free_port()
-                self.server.set_listener(("", p))
+                self.server.set_listener(("0.0.0.0", p))
                 self.server.start()
                 logger.info("Stream SIO Loop listen port {}".format(p))
                 port.register_server(g.port, p)
@@ -548,7 +553,7 @@ class StreamHTTPLoop(StreamBaseLoop):
         for _ in range(20):
             try:
                 p = port.get_free_port()
-                self.server.set_listener(("", p))
+                self.server.set_listener(("0.0.0.0", p))
                 self.server.start()
                 logger.info("Stream HTTP Loop listen port {}".format(p))
                 port.register_server(g.termPort, p)
